package org.jeecg.modules.ctop.controller;

import cn.com.ctop.common.module.utils.CtopAdConstant;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.ctop.mapper.MaterialReportOverViewMapper;
import org.jeecg.modules.ctop.service.IMaterialReportOverViewService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Created by JQ.bi on 2021.03.02
 */
@Slf4j
@RestController
@RequestMapping("/overView")
public class MaterialReportOverViewController {

    @Autowired
    private IMaterialReportOverViewService materialReportOverViewService;

    @Autowired
    private MaterialReportOverViewMapper materialReportOverViewMapper;

    /**
     *  根据userId递归查询下属，默认到最后一级，返回人员参与项目集合
     */
    @PostMapping("/getProjects")
    public Result<Set<JSONObject>> getProjects(@RequestParam String userId, @RequestParam int mediaId) {
        Result<Set<JSONObject>> result = new Result<>();
        if(userId.isEmpty()){
            result.error500("userId is empty");
            return result;
        }
        //查询所有包含自己的下级
        Set<String> subordinates= materialReportOverViewService.recursiveQuerySubordinate(userId);
        //查询并返回所有关联的项目
        result.setResult(materialReportOverViewService.queryProjectBy(subordinates,mediaId));
        result.setSuccess(true);
        return result;
    }

    /**
     *  根据筛选条件查询总消耗、视频总数、爆款视频、有效视频
     */
    @PostMapping("/sumData")
    public Result<Map<String,Object>> sumData(@RequestBody JSONObject params){
        Result<Map<String,Object>> result= new Result<>();
        Map<String, Object> totalModule = materialReportOverViewService.getTotalModule(params.getInteger("mediaId"),
                params.getString("startDate"),
                params.getString("endDate"),
                params.getJSONArray("projects"));
        result.setResult(totalModule);
        result.setSuccess(true);
        return result;
    }

    /**
     *  消耗数据趋势图
     */
    @PostMapping("/chartData")
    public Result<List<JSONObject>> chartData(@RequestBody JSONObject params){
        Result<List<JSONObject>> result =new Result<>();
        List<JSONObject> totalChat = materialReportOverViewService.getTotalChat(params.getInteger("mediaId"),
                params.getString("startDate"),
                params.getString("endDate"),
                params.getJSONArray("projects"));
        result.setResult(totalChat);
        result.setSuccess(true);
        return result;
    }

    /**
     *  Top素材排行榜
     */
    @PostMapping("/materialTop")
    public Result<List<JSONObject>> materialTop(@RequestBody JSONObject params){
        Result<List<JSONObject>> result = new Result<>();
        List<JSONObject> topMaterialList = materialReportOverViewService.getTopMaterialList(params.getInteger("mediaId"),
                params.getString("startDate"),
                params.getString("endDate"),
                params.getJSONArray("projects"));
        result.setResult(topMaterialList);
        result.setSuccess(true);
        return result;
    }

    /**
     *  Top素材排行榜查看更多
     */
    @PostMapping("/materialTopViewMore")
    public Result<PageInfo<JSONObject>> materialTopViewMore(@RequestBody JSONObject params){
        Result<PageInfo<JSONObject>> result = new Result<>();
        PageInfo<JSONObject> pageInfo = materialReportOverViewService.getTopMaterialList(params.getInteger("mediaId"),
                params.getString("startDate"),
                params.getString("endDate"),
                params.getJSONArray("projects"),
                params.getString("channelType"),
                params.getString("md5"),
                params.getString("target")==null?"cost":params.getString("target"),
                params.getString("order")==null?"desc":params.getString("order"),
                params.getInteger("pageNo"),
                params.getInteger("pageSize")
                );
        result.setResult(pageInfo);
        result.setSuccess(true);
        return result;
    }

    /**
     *  Top素材排行榜查看更多导出报表
     */


    /**
     *  Top设计排行榜
     */
    @PostMapping("/designTop")
    public Result<PageInfo<JSONObject>> designTop(@RequestBody JSONObject params){
        Result<PageInfo<JSONObject>> result = new Result<>();
        PageInfo<JSONObject> topMaterialList = materialReportOverViewService.getTopDesignList(
                params.getString("startDate"),
                params.getString("endDate"),
                params.getString("userId"),
                params.getString("target"),
                params.getString("order"),
                params.getInteger("pageSize"),
                params.getInteger("pageNo"));
        result.setResult(topMaterialList);
        result.setSuccess(true);
        return result;
    }

    /**
     *  标签占比饼状图
     */
    //TODO 需等标签库重构完
    @PostMapping("/tagProportionAnalyse")
    public Result<JSONObject> tagProportionAnalyse(){
        return null;
    }

    /**
     *  素材详情页
     */
    @PostMapping("/materialDetailInfo")
    public Result<JSONObject> materialDetailInfo(@RequestBody JSONObject params){
        Result<JSONObject> result= new Result<>();
        result.setResult(materialReportOverViewService.getMaterialDetailInfo(params.getInteger("mediaId"),
                params.getString("md5")));
        result.setSuccess(true);
        return result;

    }

    @PostMapping("/getProjectIdByMd5")
    public Result<Long> getProjectIdByMd5(@RequestBody JSONObject params){
        Result<Long> result= new Result<>();
        if (params.getInteger("mediaId") == CtopAdConstant.PLATFORM_TYPE_BYTEDANCE_INT) {
            result.setResult(materialReportOverViewMapper.queryBytedanceProjectIdByMd5(params.getString("md5")));
        } else if (params.getInteger("mediaId") == CtopAdConstant.PLATFORM_TYPE_KUAISHOU_INT) {
            result.setResult(materialReportOverViewMapper.queryKuaishouProjectIdByMd5(params.getString("md5")));
        }
        result.setSuccess(true);
        return result;
    }

    @PostMapping("/materialDetailCost")
    public Result<List<JSONObject>> materialDetailCost(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceCostByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailClick")
    public Result<List<JSONObject>> materialDetailClick(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceClickByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailMaterialShow")
    public Result<List<JSONObject>> materialDetailMaterialShow(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceMaterialShowByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailPlay100Rate")
    public Result<List<JSONObject>> materialDetailPlay100Rate(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedancePlay100RateByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailLikeMaterial")
    public Result<List<JSONObject>> materialDetailLikeMaterial(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceLikeMaterialByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailCommentMaterial")
    public Result<List<JSONObject>> materialDetailCommentMaterial(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceCommentMaterialByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailShareMaterial")
    public Result<List<JSONObject>> materialDetailShareMaterial(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceShareMaterialByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailFollow")
    public Result<List<JSONObject>> materialDetailFollow(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryBytedanceFollowByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailCharge")
    public Result<List<JSONObject>> materialDetailCharge(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouChargeByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailPhotoShow")
    public Result<List<JSONObject>> materialDetailPhotoShow(@RequestBody JSONObject params){
        Result<List<JSONObject>>  result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouPhotoShowByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailPhotoClick")
    public Result<List<JSONObject>> materialDetailPhotoClick(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouPhotoClickByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailAClick")
    public Result<List<JSONObject>> materialDetailAClick(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouAClickByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailBClick")
    public Result<List<JSONObject>> materialDetailBClick(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouBClickByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailActivation")
    public Result<List<JSONObject>> materialDetailActivation(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouActivationByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }
    @PostMapping("/materialDetailPlay3sRate")
    public Result<List<JSONObject>> materialDetailPlay3sRate(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewMapper.queryKuaishouPlay3sRateByMd5(params.getString("md5"),params.getLong("projectId")));
        result.setSuccess(true);
        return result;
    }

    @PostMapping("/materialDetailChat")
    public Result<List<JSONObject>> materialDetailChat(@RequestBody JSONObject params){
        Result<List<JSONObject>> result= new Result<>();
        result.setResult(materialReportOverViewService.getMaterialDetailChat(params.getInteger("mediaId"),
                params.getString("md5")));
        result.setSuccess(true);
        return result;
    }
}
